---
title: <span class="badge builder"></span> Scenario
---
# <span class="badge builder"></span> Scenario

## Constructor

```python
Scenario()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.Scenario
```

### <span class="badge object-method"></span> description

```python
def description(description: str) -> typing.Self
```

### <span class="badge object-method"></span> hide_alias_field

```python
def hide_alias_field(hide_alias_field: bool) -> typing.Self
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: str) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> string_input

```python
def string_input(string_input: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Scenario](./object-Scenario.md)
